pub fn encoded_size(envelope: &ValueEnvelope) -> usizeExpand description
Get the size of an encoded envelope in bytes
Useful for debugging and monitoring serialization overhead.
pub fn encoded_size(envelope: &ValueEnvelope) -> usizeGet the size of an encoded envelope in bytes
Useful for debugging and monitoring serialization overhead.