Module print_result

Module print_result 

Wire print result - for terminal display

This module defines the structure for values that have been pre-formatted or are destined for terminal output with ANSI colors.

Structs

PrintResult
Represents a result intended for printing to the terminal
WirePrintResult
Result of a print statement or REPL expression

Enums

WirePrintSpan
A span of text within a print result