Module memoized

Module memoized 

Memoized transport wrapper that caches results of remote function calls.

Caches results by SHA-256(destination || payload) using an LRU cache. Intercepts Transport::send before forwarding to the inner transport, returning the cached result when available.

Structs

MemoConfig
Configuration for the memoized transport.
MemoStats
Cache hit/miss statistics.
MemoizedTransport
Memoized transport wrapper with LRU eviction.