pub struct ValueEnvelope {
pub value: WireValue,
pub type_info: TypeInfo,
pub type_registry: TypeRegistry,
}Expand description
Complete value envelope with metadata
This is the primary exchange format for Shape values. It contains:
- The raw value (for lossless data transfer)
- Type information (for proper interpretation)
- Type registry (for metadata and display options)
Fields
value: WireValueThe wire-format value
type_info: TypeInfoType information
type_registry: TypeRegistryAvailable metadata items for display/parsing
Implementations
Sourceimpl ValueEnvelope
impl ValueEnvelope
Sourcepub fn new(
value: WireValue,
type_info: TypeInfo,
type_registry: TypeRegistry,
) -> Self
pub fn new( value: WireValue, type_info: TypeInfo, type_registry: TypeRegistry, ) -> Self
Create a new envelope
Sourcepub fn from_value(value: WireValue) -> Self
pub fn from_value(value: WireValue) -> Self
Create an envelope with default metadata inferred from the value
Sourcepub fn default_format(&self) -> &str
pub fn default_format(&self) -> &str
Get the default format name
Sourcepub fn available_formats(&self) -> Vec<&str>
pub fn available_formats(&self) -> Vec<&str>
Get available metadata/format names
Sourcepub fn has_format(&self, name: &str) -> bool
pub fn has_format(&self, name: &str) -> bool
Check if a metadata item is available
Sourcepub fn format_default(&self) -> Result<String>
pub fn format_default(&self) -> Result<String>
Format the value using the default format
Sourceimpl ValueEnvelope
impl ValueEnvelope