Wire print result - for terminal display
This module defines the structure for values that have been pre-formatted or are destined for terminal output with ANSI colors.
Structs
- Print
Result - Represents a result intended for printing to the terminal
- Wire
Print Result - Result of a print statement or REPL expression
Enums
- Wire
Print Span - A span of text within a print result